@@ -84,6 +84,7 @@ def parse_cmdlineoptions(arglist):
 	for opt, arg in optlist:
 		if opt == "-b" or opt == "--backup-mode": action = "backup"
 		elif opt == "--calculate-average": action = "calculate-average"
+		elif opt == "--carbonfile": Globals.set("carbonfile_active", 1)
 		elif opt == "--check-destination-dir": action = "check-destination-dir"
 		elif opt == "--compare" or opt == "--compare-at-time":
 			action = "compare"
@@ -424,8 +425,13 @@ def backup_set_fs_globals(rpin, rpout):
 	update_triple(src_fsa.resource_forks, dest_fsa.resource_forks,
 				  ('resource_forks_active', 'resource_forks_write',
 				   'resource_forks_conn'))
+
 	update_triple(src_fsa.carbonfile, dest_fsa.carbonfile,
 				  ('carbonfile_active', 'carbonfile_write', 'carbonfile_conn'))
+	if src_fsa.carbonfile and not Globals.carbonfile_active:
+		Log("Source may have carbonfile support, but support defaults to "
+			"off.\n  Use --carbonfile to enable.", 5)
+
 	if Globals.never_drop_acls and not Globals.acls_active:
 		Log.FatalError("--never-drop-acls specified, but ACL support\n"
 					   "disabled on destination filesystem")
@@ -435,9 +441,9 @@ def backup_set_fs_globals(rpin, rpout):
 	SetConnections.UpdateGlobal('fsync_directories', dest_fsa.fsync_dirs)
 	SetConnections.UpdateGlobal('change_ownership', dest_fsa.ownership)
 	SetConnections.UpdateGlobal('chars_to_quote', dest_fsa.chars_to_quote)
-	if Globals.chars_to_quote:
-		for conn in Globals.connections:
-			conn.FilenameMapping.set_init_quote_vals()
+	if not dest_fsa.high_perms:
+		SetConnections.UpdateGlobal('permission_mask', 0777)
+	if Globals.chars_to_quote: FilenameMapping.set_init_quote_vals()
 	
 def backup_touch_curmirror_local(rpin, rpout):
 	"""Make a file like current_mirror.time.data to record time
@@ -542,6 +548,8 @@ def restore_set_fs_globals(target):
 	if Globals.preserve_hardlinks != 0:
 		SetConnections.UpdateGlobal('preserve_hardlinks', target_fsa.hardlinks)
 	SetConnections.UpdateGlobal('change_ownership', target_fsa.ownership)
+	if not target_fsa.high_perms:
+		SetConnections.UpdateGlobal('permission_mask', 0777)
 
 	if Globals.chars_to_quote is None: # otherwise already overridden
 		if mirror_fsa.chars_to_quote:
@@ -722,6 +730,7 @@ def single_set_fs_globals(rbdir):
 		SetConnections.UpdateGlobal('preserve_hardlinks', fsa.hardlinks)
 	SetConnections.UpdateGlobal('fsync_directories', fsa.fsync_dirs)
 	SetConnections.UpdateGlobal('change_ownership', fsa.ownership)
+	if not fsa.high_perms: SetConnections.UpdateGlobal('permission_mask', 0777)
 	SetConnections.UpdateGlobal('chars_to_quote', fsa.chars_to_quote)
 	if Globals.chars_to_quote:
 		for conn in Globals.connections:
