@@ -138,9 +138,9 @@ def RORP2Record(rorpath):
 	# Add user, group, and permission information
 	uid, gid = rorpath.getuidgid()
 	str_list.append("  Uid %s\n" % uid)
-	str_list.append("  Uname %s\n" % rorpath.getuname() or ":")
+	str_list.append("  Uname %s\n" % (rorpath.getuname() or ":"))
 	str_list.append("  Gid %s\n" % gid)
-	str_list.append("  Gname %s\n" % rorpath.getgname() or ":")
+	str_list.append("  Gname %s\n" % (rorpath.getgname() or ":"))
 	str_list.append("  Permissions %s\n" % rorpath.getperms())
 	return "".join(str_list)
 
@@ -177,13 +177,14 @@ def Record2RORP(record_string):
 		elif field == "Uid": data_dict['uid'] = int(data)
 		elif field == "Gid": data_dict['gid'] = int(data)
 		elif field == "Uname":
-			if data == ":": data_dict['uname'] = None
+			if data == ":" or data == 'None': data_dict['uname'] = None
 			else: data_dict['uname'] = data
 		elif field == "Gname":
-			if data == ':': data_dict['gname'] = None
+			if data == ':' or data == 'None': data_dict['gname'] = None
 			else: data_dict['gname'] = data
 		elif field == "Permissions": data_dict['perms'] = int(data)
-		else: raise ParsingError("Unknown field in line '%s'" % line)
+		else: raise ParsingError("Unknown field in line '%s %s'" %
+								 (field, data))
 	return rpath.RORPath(index, data_dict)
 
 chars_to_quote = re.compile("\\n|\\\\")
